@@ -11,13 +11,16 @@ def extract_article(article_url: str)-> bs4.element.Tag:
     # print(soup.prettify())
     article = soup.find(attrs={'class': 'article-body article'})
     # remove image tags
-    images = [x.extract() for x in article.findAll('img')]
-    # remove spans with Click Image to View Full Size
-    image_text = article.findAll(lambda tag : tag.name == 'span' and 'Click Image To View Full Size' in tag.text)
-    [x.extract() for x in image_text]
+    try:
+        image_text = article.findAll(lambda tag : tag.name == 'span' and 'Click Image To View Full Size' in tag.text)
+        [x.extract() for x in image_text]
+        images = [x.extract() for x in soup.findAll('img')]
+    except AttributeError as e:
+        print(e)
     return article
 
-def save_bs4_tag(tag, file_name=''):
+def save_bs4_tag(tag: bs4.element.Tag, file_name: str=''):
+    """Save bs4 tag to file"""
     with open(file_name, "w", encoding='utf-8') as f:
         f.write(tag.text)
 
